@@ -10,7 +10,6 @@ from django.conf import settings
 from django.db.models.loading import get_model
 from django.utils.translation import ugettext_lazy as _
 from coop.utils.autocomplete_admin import FkAutocompleteAdmin, InlineAutocompleteAdmin
-from django_extensions.admin import ForeignKeyAutocompleteAdmin
 
 from coop_local.models import Contact, Person
 from coop_geo.models import Location
@@ -54,6 +53,8 @@ class EngagementInline(InlineAutocompleteAdmin):
     model = get_model('coop_local', 'Engagement')
     verbose_name = _(u'Member')
     verbose_name_plural = _(u'Members')
+    fields = ('person', 'role', 'role_detail', 'org_admin', 'engagement_display')
+
     related_search_fields = {'person': ('last_name', 'first_name',
                                         'email', 'structure', 'username'), }
     extra = 2
@@ -64,7 +65,7 @@ class RelationInline(InlineAutocompleteAdmin):
     fk_name = 'source'
     readonly_fields = ('created',)
     fields = ('reltype', 'target', 'created')
-    related_search_fields = {'target': ('title', 'subtitle', 'description'), }
+    related_search_fields = {'target': ('title', 'subtitle', 'acronym', 'description'), }
     extra = 1
 
 
@@ -72,10 +73,17 @@ class OrgInline(InlineAutocompleteAdmin):
     model = get_model('coop_local', 'Engagement')
     verbose_name = _(u'Engagement')
     verbose_name_plural = _(u'Engagements')
-    related_search_fields = {'organization': ('title', 'subtitle', 'description'), }
+    fields = ('organization', 'role', 'role_detail', 'engagement_display')
+
+    related_search_fields = {'organization': ('title', 'subtitle', 'acronym', 'description'), }
     extra = 1
 
 
+# class RoleAdmin(admin.ModelAdmin):
+#     list_display = ('label', 'category')
+#     list_editable = ('category',)
+
+
 class OrganizationAdminForm(forms.ModelForm):
     description = forms.CharField(widget=AdminTinyMCE(attrs={'cols': 80, 'rows': 60}), required=False)
 
@@ -95,7 +103,7 @@ class OrganizationAdminForm(forms.ModelForm):
         self.fields['pref_phone'].queryset = org_contacts.filter(category=1)
         self.fields['category'].help_text = None
 
-        member_locations_id = [m.location.id for m in 
+        member_locations_id = [m.location.id for m in
             Person.objects.filter(id__in=members_id).exclude(location=None)]  # limit SQL to location field
 
         self.fields['pref_address'].queryset = Location.objects.filter(
@@ -113,11 +121,11 @@ def create_action(category):
 
 
 class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
-    change_form_template = 'admintools_bootstrap/tabbed_change_form.html' 
+    change_form_template = 'admintools_bootstrap/tabbed_change_form.html'
     form = OrganizationAdminForm
     list_display = ['logo_list_display', 'label', 'active', 'has_description', 'has_location']
     list_display_links = ['label', ]
-    search_fields = ['title', 'acronym', 'subtitle', 'description']
+    search_fields = ['title', 'acronym', 'subtitle', 'acronym', 'description']
     list_filter = ['active', 'category']
     #actions_on_top = True
     #actions_on_bottom = True
@@ -130,7 +138,7 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
     formfield_overrides = {
         URLField: {'widget': URLFieldWidget},
     }
-    
+
     if "coop.exchange" in settings.INSTALLED_APPS:
         inlines = [ ContactInline,
                         EngagementInline,
@@ -139,18 +147,18 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
                         LocatedInline,
                         AreaInline,
                         ]
-    else: 
+    else:
         inlines = [ ContactInline,
                     EngagementInline,
                     LocatedInline,
                     ]
 
-    # grace au patch 
+    # grace au patch
     # https://code.djangoproject.com/ticket/17856
     # https://github.com/django/django/blob/master/django/contrib/admin/options.py#L346
     # def get_inline_instances(self, request, obj):
     #     inline_instances = []
-        
+
     #     for inline_class in self.inlines:
     #         if inline_class.model == get_model('coop_local', 'Exchange'):
     #             inline = inline_class(self.model, self.admin_site, obj=obj)
@@ -161,16 +169,16 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
 
     fieldsets = (
         ('Identité', {
-            'fields': ('logo', 'title', ('acronym', 'pref_label'), 'subtitle', ('birth', 'active',),
-                        'web')
+            'fields': ['logo', 'title', ('acronym', 'pref_label'), 'subtitle', ('birth', 'active',),
+                        'web']
             }),
         ('Description', {
-            'fields': ('description', 'category', 'tags', )
+            'fields': ['description', 'category',]  # 'tags', )
             }),
 
         ('Préférences', {
             #'classes': ('collapse',),
-            'fields': ('pref_email', 'pref_phone', 'pref_address', 'notes',)
+            'fields': ['pref_email', 'pref_phone', 'pref_address', 'notes',]
         })
     )
 
@@ -186,4 +194,4 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
 
     class Media:
         js = ('/static/js/admin_customize.js',)
- 
+
