@@ -1,5 +1,7 @@
 # -*- coding:utf-8 -*-
 from django.db import models
+from autoslug import AutoSlugField
+#from mptt.models import MPTTModel, TreeForeignKey
 from extended_choices import Choices
 from django_extensions.db import fields as exfields
 from django.utils.translation import ugettext_lazy as _
@@ -11,9 +13,89 @@ from django.conf import settings
 from coop.models import URIModel
 from sorl.thumbnail import ImageField
 from sorl.thumbnail import default
-ADMIN_THUMBS_SIZE = '60x60' 
+import rdflib
+import logging
 
 
+ADMIN_THUMBS_SIZE = '60x60'
+
+
+# class BaseClassification(MPTTModel, URIModel):
+#     label = models.CharField(_(u'label'), max_length=60)
+#     slug = AutoSlugField(populate_from='label', always_update=True, unique=True)
+#     parent = TreeForeignKey('self', null=True, blank=True, related_name='children')
+
+#     domain_name = 'data.economie-solidaire.fr'
+
+#     class MPTTMeta:
+#         order_insertion_by = ['label']
+
+#     class Meta:
+#         abstract = True
+#         verbose_name = _('Classification')
+#         verbose_name_plural = _('Classifications')
+#         ordering = ['tree_id', 'lft']  # for FeinCMS TreeEditor
+#         app_label = 'coop_local'
+
+#     def __unicode__(self):
+#         return unicode(self.label)
+
+#     def get_absolute_url(self):
+#         return reverse('%s-detail' % self._meta.object_name.lower(), args=[self.slug])
+
+#     @property
+#     def uri_id(self):
+#         return self.slug
+
+#     def uri_registry(self):
+#         return u'label'
+
+
+class BaseRoleCategory(models.Model):
+    label = models.CharField(_(u'label'), max_length=60)
+    slug = exfields.AutoSlugField(populate_from=('label'), overwrite=True)
+    uri = models.CharField(_(u'URI'), blank=True, max_length=250)
+
+    class Meta:
+        abstract = True
+        ordering = ['label']
+        verbose_name = _('Role category')
+        verbose_name_plural = _('Role categories')
+        #ordering = ['label']
+        app_label = 'coop_local'
+
+    def __unicode__(self):
+        return unicode(self.label)
+
+
+class BaseRole(URIModel):
+    label = models.CharField(_(u'label'), max_length=60)
+    slug = AutoSlugField(populate_from='label', always_update=True, unique=True)
+    category = models.ForeignKey('coop_local.RoleCategory', null=True, blank=True, verbose_name=_(u'category'))
+
+    domain_name = 'data.economie-solidaire.fr'
+
+    class Meta:
+        abstract = True
+        verbose_name = _('Role')
+        verbose_name_plural = _('Roles')
+        #ordering = ['tree_id', 'lft']  # for FeinCMS TreeEditor
+        #ordering = ['label']
+        app_label = 'coop_local'
+
+    @property
+    def uri_id(self):
+        return self.slug
+
+    def uri_registry(self):
+        return u'label'
+
+    def __unicode__(self):
+        return unicode(self.label)
+
+    def get_absolute_url(self):
+        return reverse('role_detail', args=[self.slug])
+
 DISPLAY = Choices(
     ('PUBLIC',  1,  _(u'public information')),
     ('USERS',   2,  _(u'registered users')),
@@ -40,13 +122,13 @@ COMM_MEANS = Choices(
 
 
 # A model to deal with how contact (an organization, persone,...)
-# mail,fax, ... see COMM_MEANS 
+# mail,fax, ... see COMM_MEANS
 class BaseContact(URIModel):
-    category = models.PositiveSmallIntegerField(_(u'Category'), 
+    category = models.PositiveSmallIntegerField(_(u'Category'),
                     choices=COMM_MEANS.CHOICES)
     content = models.CharField(_(u'content'), max_length=250)
     details = models.CharField(_(u'details'), blank=True, max_length=100)
-    display = models.PositiveSmallIntegerField(_(u'Display'), 
+    display = models.PositiveSmallIntegerField(_(u'Display'),
                     choices=DISPLAY.CHOICES, default=DISPLAY.PUBLIC)
     content_type = models.ForeignKey(ContentType, blank=True, null=True)
     object_id = models.PositiveIntegerField()
@@ -57,17 +139,21 @@ class BaseContact(URIModel):
         ordering = ['category']
         verbose_name = _(u'Contact')
         verbose_name_plural = _(u'Contacts')
+        app_label = 'coop_local'
 
     def __unicode__(self):
         if self.content_object != None:
             return self.content + u' (' + self.content_object.__unicode__() + u')'
-        else:    
+        else:
             return self.content
 
+    def label(self):
+        return self.__unicode__()
+
     def clean(self):
         if self.category in [1, 2, 3]:
             import re
-            phoneSplitRegex = re.compile(r"[\-\(\) \.\,]")         
+            phoneSplitRegex = re.compile(r"[\-\(\) \.\,]")
             parts = phoneSplitRegex.split(self.content)
             num = ''.join(parts)
             if len(num) == 10:
@@ -77,29 +163,8 @@ class BaseContact(URIModel):
 
     def save(self, *args, **kwargs):
         self.clean()
-        super(BaseContact, self).save(*args, **kwargs) 
-
-
-class BaseRole(URIModel):
-    label = models.CharField(_(u'label'), max_length=60)
-    slug = exfields.AutoSlugField(populate_from=('label'), overwrite=True)
-
-    domain_name = 'data.economie-solidaire.fr'
-
-    @property
-    def uri_id(self):
-        return self.slug
-
-
-    class Meta:
-        abstract = True
-        ordering = ['label']
-
-    def __unicode__(self):
-        return unicode(self.label)
-
-    def get_absolute_url(self):
-        return reverse('role_detail', args=[self.slug])
+        #logging.error(u'A contact has been created or modified', exc_info=True, extra={'request': request})
+        super(BaseContact, self).save(*args, **kwargs)
 
 
 RELATIONS = Choices(
@@ -121,8 +186,11 @@ class BaseRelation(models.Model):
 
     class Meta:
         abstract = True
+        verbose_name = _('Relation')
+        verbose_name_plural = _('Relations')
+        app_label = 'coop_local'
 
-    def __unicode__(self):    
+    def __unicode__(self):
         return u'"' + self.source.__unicode__() + u'"' + \
             unicode(RELATIONS.CHOICES_DICT[self.reltype]) + \
             u'"' + self.target.__unicode__() + u'".'
@@ -133,20 +201,31 @@ class BaseRelation(models.Model):
 
 
 class BaseEngagement(URIModel):
-    person = models.ForeignKey('coop_local.Person', verbose_name=_(u'person'), related_name='engagements') 
-    organization = models.ForeignKey('coop_local.Organization', verbose_name=_(u'organization')) 
-    role = models.ForeignKey('coop_local.Role', verbose_name=_(u'role'))
+    person = models.ForeignKey('coop_local.Person', verbose_name=_(u'person'), related_name='engagements')
+    organization = models.ForeignKey('coop_local.Organization', verbose_name=_(u'organization'))
+    role = models.ForeignKey('coop_local.Role', verbose_name=_(u'role'), null=True, blank=True)
     role_detail = models.CharField(_(u'detailed role'), blank=True, max_length=100)
     org_admin = models.BooleanField(_(u'has editor rights'), default=True)
     engagement_display = models.PositiveSmallIntegerField(_(u'Display'), choices=DISPLAY.CHOICES, default=DISPLAY.PUBLIC)
 
+    remote_role_uri = models.CharField(_(u'URI'), blank=True, null=True, max_length=250)
+    remote_role_label = models.CharField(blank=True, max_length=100)
+
     class Meta:
         abstract = True
         verbose_name = _('Engagement')
         verbose_name_plural = _('Engagements')
+        app_label = 'coop_local'
 
     def __unicode__(self):
-        return self.person.__unicode__()
+        return '%(person)s, %(role)s @ %(org)s' % {
+                    'person': self.person.__unicode__(),
+                    'role': self.role.__unicode__(),
+                    'org': self.organization.__unicode__()
+                    }
+
+    def label(self):
+        return self.__unicode__()
 
 
 class BaseOrganizationCategory(models.Model):
@@ -157,6 +236,7 @@ class BaseOrganizationCategory(models.Model):
         abstract = True
         verbose_name = _(u'organization category')
         verbose_name_plural = _(u'organization categories')
+        app_label = 'coop_local'
 
     def __unicode__(self):
         return self.label
@@ -177,10 +257,10 @@ class BaseOrganization(URIModel):
     title = models.CharField(_(u'title'), max_length=250)
 
     acronym = models.CharField(_(u'acronym'), max_length=20, blank=True, null=True)
-    pref_label = models.PositiveSmallIntegerField(_(u'Preferred label'), 
+    pref_label = models.PositiveSmallIntegerField(_(u'Preferred label'),
                         choices=PREFLABEL.CHOICES, default=PREFLABEL.TITLE)
 
-    subtitle = models.CharField(_(u'tagline'), blank=True, null=True, 
+    subtitle = models.CharField(_(u'tagline'), blank=True, null=True,
                 max_length=250,
                 help_text=_(u'tell us what your organization do in one line.'))
 
@@ -188,38 +268,38 @@ class BaseOrganization(URIModel):
 
     logo = ImageField(upload_to='logos/', null=True, blank=True)
 
-    relations = models.ManyToManyField('coop_local.Organization', 
-                symmetrical=False, through='coop_local.Relation', 
+    relations = models.ManyToManyField('coop_local.Organization',
+                symmetrical=False, through='coop_local.Relation',
                 verbose_name=_(u'relations'))
 
-    category = models.ManyToManyField('coop_local.OrganizationCategory', 
+    category = models.ManyToManyField('coop_local.OrganizationCategory',
                 blank=True, null=True, verbose_name=_(u'category'))
 
-    members = models.ManyToManyField('coop_local.Person', 
+    members = models.ManyToManyField('coop_local.Person',
                 through='coop_local.Engagement', verbose_name=_(u'members'))
 
     contacts = generic.GenericRelation('coop_local.Contact')
     subs = generic.GenericRelation('coop_local.Subscription')
 
-    # coop_geo must be loaded BEFORE coop_local
+    # ORDER : coop_geo must be loaded BEFORE coop_local
     if "coop_geo" in settings.INSTALLED_APPS:
-        located = generic.GenericRelation('coop_geo.Located')
-        framed = generic.GenericRelation('coop_geo.AreaLink')
+        located = generic.GenericRelation('coop_geo.Located')  # , related_name='located_org')
+        framed = generic.GenericRelation('coop_geo.AreaLink')  # , related_name='framed_org')
 
     birth = models.DateField(_(u'creation date'), null=True, blank=True)
     email = models.EmailField(_(u'global email'), blank=True, null=True)
-    email_sha1 = models.CharField(_(u'email checksum'), 
+    email_sha1 = models.CharField(_(u'email checksum'),
             max_length=250, blank=True, null=True)  # TODO : do this in Postgre
     web = models.URLField(_(u'web site'), blank=True, null=True)
 
-    pref_email = models.ForeignKey('coop_local.Contact', 
-                verbose_name=_(u'preferred email'), 
+    pref_email = models.ForeignKey('coop_local.Contact',
+                verbose_name=_(u'preferred email'),
                 related_name="pref_email", null=True, blank=True)
-    pref_phone = models.ForeignKey('coop_local.Contact', 
-                verbose_name=_(u'preferred phone'), 
+    pref_phone = models.ForeignKey('coop_local.Contact',
+                verbose_name=_(u'preferred phone'),
                 related_name='pref_phone', null=True, blank=True)
-    pref_address = models.ForeignKey('coop_geo.Location', 
-                verbose_name=_(u'preferred postal address'), 
+    pref_address = models.ForeignKey('coop_geo.Location',
+                verbose_name=_(u'preferred postal address'),
                 related_name='pref_adress', null=True, blank=True)
 
     slug = exfields.AutoSlugField(populate_from='title', blank=True, overwrite=True)
@@ -231,6 +311,7 @@ class BaseOrganization(URIModel):
         ordering = ['title']
         verbose_name = _(u'Organization')
         verbose_name_plural = _(u'Organizations')
+        app_label = 'coop_local'
 
     def __unicode__(self):
         return unicode(self.title)
@@ -248,7 +329,7 @@ class BaseOrganization(URIModel):
 
         def has_location(self):
             return self.located.all().count() > 0
-        has_location.boolean = True    
+        has_location.boolean = True
         has_location.short_description = _(u'geo')
 
         def locations(self):
@@ -261,7 +342,7 @@ class BaseOrganization(URIModel):
 
     def has_description(self):
         return self.description != None and len(self.description) > 20
-    has_description.boolean = True    
+    has_description.boolean = True
     has_description.short_description = _(u'desc.')
 
     def logo_list_display(self):
@@ -269,9 +350,9 @@ class BaseOrganization(URIModel):
             thumb = default.backend.get_thumbnail(self.logo.file, ADMIN_THUMBS_SIZE)
             return '<img width="%s" src="%s" />' % (thumb.width, thumb.url)
         else:
-            return _(u"No Image") 
+            return _(u"No Image")
     logo_list_display.short_description = _(u"logo")
-    logo_list_display.allow_tags = True   
+    logo_list_display.allow_tags = True
 
     #@models.permalink
     def get_absolute_url(self):
@@ -318,13 +399,54 @@ class BaseOrganization(URIModel):
                 if locations.count() == 1:
                     self.pref_address = locations[0].location
 
-
         # TODO move this to Contact model or do it in SQL
 
-        # if self.email and self.email != '': 
+        # if self.email and self.email != '':
         #     import hashlib
         #     m = hashlib.sha1()
         #     m.update(self.email)
         #     self.email_sha1 = m.hexdigest()
-        super(BaseOrganization, self).save(*args, **kwargs)  
+        super(BaseOrganization, self).save(*args, **kwargs)
 
+
+    # title field needs a special handling. checkDirectMap does not work
+    # because two rdf property use the coop_local_organization.title field
+    # Thus we have to decide which one to use
+    def updateField_title(self, dbfieldname, graph):
+            title = list(graph.objects(rdflib.term.URIRef(self.uri), settings.NS.legal.legalName))
+            if len(title) == 1:
+                self.title = title[0]
+                print "For id %s update the field %s" % (self.id, dbfieldname)
+            elif len(title) == 0:
+                title = list(graph.objects(rdflib.term.URIRef(self.uri), settings.NS.rdfs.label))
+                if len(title) == 1:
+                    self.title = title[0]
+                    print "For id %s update the field %s" % (self.id, dbfieldname)
+                else:
+                    print "    The field %s cannot be updated." % dbfieldname
+            else:
+                print "    The field %s cannot be updated." % dbfieldname
+
+
+    def updateField_pref_label(self, dbfieldname, graph):
+        prefLabel = list(graph.objects(rdflib.term.URIRef(self.uri), settings.NS.rdfs.label))
+        if len(prefLabel) == 1:
+            legalName = list(graph.objects(rdflib.term.URIRef(self.uri), settings.NS.legal.legalName))
+            if len(legalName) == 1:
+                if prefLabel[0] == legalName[0]:
+                    self.pref_label = PREFLABEL.TITLE
+                    print "For id %s update the field %s" % (self.id, dbfieldname)
+
+            else:
+                acronym = list(graph.objects(rdflib.term.URIRef(self.uri), settings.NS.ov.acronym))
+                if len(acronym) == 1:
+                    if prefLabel[0] == acronym[0]:
+                        self.pref_label = PREFLABEL.ACRO
+                        print "For id %s update the field %s" % (self.id, dbfieldname)
+
+                    else:
+                        print "    The field %s cannot be updated." % dbfieldname
+                else:
+                    print "    The field %s cannot be updated." % dbfieldname
+        else:
+            print "    The field %s cannot be updated." % dbfieldname
