@@ -1,5 +1,5 @@
 # -*- coding:utf-8 -*-
-# -*- coding:utf-8 -*-
+
 from django.conf.urls.defaults import patterns, include, url
 from django.views.generic.base import TemplateView, RedirectView
 from django.conf import settings
@@ -23,6 +23,8 @@ urlpatterns = patterns('',
     (r'^membre/', include('coop.person.urls')),
 
     url(r'^feed/(?P<model>[\w-]+)/$', UpdateFeed()),
+    url(r'^hub/', include('subhub.urls')),
+    url(r'^subscriber/', include('django_push.subscriber.urls')),  # Callback
 
     url(r'^robots\.txt$', TextPlainView.as_view(template_name='robots.txt')),
     url(r'^favicon\.ico$', RedirectView.as_view(url='/static/img/favicon.ico')),
@@ -31,7 +33,11 @@ urlpatterns = patterns('',
 )
 
 if 'coop.exchange' in settings.INSTALLED_APPS:
-
     urlpatterns = urlpatterns + patterns('',
         (r'^annonces/', include('coop.exchange.urls')),
     )
+
+if 'coop.webid' in settings.INSTALLED_APPS:
+    urlpatterns = urlpatterns + patterns('',
+        (r'^webid/', include('coop.webid.urls')),
+    )
\ No newline at end of file
